﻿#Skill 3.2 Managing Software-Defined Storage

#Implement Storage Replica
$array1 = Get-SCStorageArray -Name “Primary Array”
$array2 = Get-SCStorageArray -Name “Secondary Array”
$pool1 = Get-SCStoragePool | ? StorageArray -eq $array1 | ? Name -match “Pool 1”
$pool2 = Get-SCStoragePool | ? StorageArray -eq $array2 | ? Name -match “Pool 2”

Set-SCStorageArray -Pair -StorageArray $array1 -PeerStorageArray $array2.Name
$vol1data = New-SCStorageVolume -StorageArray $array1 -StoragePool $pool1 -Name “vol1_data” -SizeInBytes $vol1dataSize -RunAsynchronously -PhysicalDiskRedundancy 2 -FileSystem CSVFS_NTFS -GuidPartitionTable
$vol1log = New-SCStorageVolume -StorageArray $array1 -StoragePool  $pool1 -Name “vol1_log” -SizeInBytes $vol1logSize -RunAsynchronously -PhysicalDiskRedundancy 2 -FileSystem NTFS -GuidPartitionTable
$vol1 = New-SCReplicationGroup -CreateOnArray -Name “vol1” -StorageVolume $vol1data -LogStorageVolume $vol1log

$vol2data = New-SCStorageVolume -StorageArray $array2 -StoragePool $pool2 -Name “vol2_data” -SizeInBytes $vol2dataSize -RunAsynchronously -PhysicalDiskRedundancy 2 -FileSystem CSVFS_NTFS -GuidPartitionTable
$vol2log = New-SCStorageVolume -StorageArray $array2 -StoragePool  $pool2 -Name “vol2_log” -SizeInBytes $vol2logSize -RunAsynchronously -PhysicalDiskRedundancy 2 -FileSystem NTFS -GuidPartitionTable
$vol2 = New-SCReplicationGroup -CreateOnArray -Name “vol2” -StorageVolume $vol2data -LogStorageVolume $vol2log

Set-SCReplicationGroup -ReplicationGroup $vol1 -Operation EnableProtection -TargetReplicationGroup $vol2 -EnableProtectionMode Synchronous

Read-SCStorageProvider -StorageProvider $array1.StorageProvider
Read-SCStorageProvider -StorageProvider $array2.StorageProvider

Get-SCReplicationGroup | ft Name, IsPrimary, ReplicationState, ReplicationHealth

#Implement Hyper-V Replica
Add-ClusterServerRole -Name “HVR-Broker” -StaticAddress 10.184.108.100
Add-ClusterResource -Name “Virtual Machine Replication Broker” -Type “Virtual Machine Replication Broker” -Group “HVR-Broker”
Add-ClusterResourceDependency “Virtual Machine Replication Broker” “HVR-Broker”
Start-ClusterGroup “HVR-Broker”

Enable-VMReplication -VMName “VM01” -ReplicaServerName “HVR-Broker.contoso.int” -ReplicaServerPort 80 -AuthenticationType Kerberos

#Optimize S2D
Optimize-StoragePool S2D*

#Implement Network QoS for storage
Install-WindowsFeature Data-Center-Bridging
New-NetQoSPolicy “SMB” -NetDirectPortMatchCondition 445 -PriorityValue8021Action 3
Enable-NetQoSFlowControl -Priority 3
Disable-NetQoSFlowControl -Priority 0,1,2,4,5,6,7
New-NetQoSTrafficClass “SMB” -Priority 3 -BandwidthPercentage 30 -Algorithm ETS
Enable-NetAdapterQos -InterfaceAlias “Ethernet 1”
Enable-NetAdapterQoS -InterfaceAlias “Ethernet 2”

